@@ -1,12 +1,13 @@
 import gitissius.commands as commands
 import gitissius.gitshelve as gitshelve
+import gitissius.common as common
 
 class Command(commands.GitissiusCommand):
     """
     Pull issues to repo
     """
     name="pull"
-    help="Pull issues to origin master"
+    help="Pull issues to origin"
 
     def _execute(self, options, args):
         # save current branch name
@@ -41,3 +42,7 @@ class Command(commands.GitissiusCommand):
         except gitshelve.GitError, error:
             # no worries, no stash to apply
             pass
+
+        # build issue list cache
+        common.issue_manager.update_db()
+
